@@ -25,7 +25,7 @@
 
 #include <KLocalizedString>
 #include "ksirkskineditor_debug.h"
-#include <qsvgrenderer.h>
+#include <QSvgRenderer>
 #include <QString>
 #include <QApplication>
 #include <QDataStream>
